@@ -38,10 +38,17 @@ TITLE_CHOICES = Choices(
 
 LANDING_PAGE_NEW = 1
 LANDING_PAGE_CUSTOMER = 2
+EXISTING_STROER_LANDINGPAGE = 3
 LANDING_PAGE_CHOICES = Choices(
     (LANDING_PAGE_NEW, 'new', _('New website')),
     (LANDING_PAGE_CUSTOMER, 'customer', _('Customer website')),
 )
+SEO_LANDING_PAGE_CHOICES = Choices(
+    (LANDING_PAGE_NEW, 'new', _('New website')),
+    (LANDING_PAGE_CUSTOMER, 'customer', _('Customer website')),
+    (EXISTING_STROER_LANDINGPAGE, 'existing_stroer_lp', _('Existing Stroer Landing Page')),
+)
+
 
 PRODUCT_LEVEL_BASIC = 1
 PRODUCT_LEVEL_PREMIUM = 2
@@ -1178,7 +1185,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
 
     '''
     where should the native advertisement be linked?
-    required for `native_ad_out` and `native_ad_flow_ad_out` ads types
     '''
     target_url = serializers.URLField(max_length=400, allow_blank=True, required=False)
 
@@ -1255,10 +1261,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
             NATIVE_AD_TYPES.native_ad_flow_ad_out: [BILLING_TYPES.cpm],
             NATIVE_AD_TYPES.native_ad_flow_ad_prospect: [BILLING_TYPES.cpm],
         }
-        TARGET_URL_REQUIRED_FOR = [
-            NATIVE_AD_TYPES.native_ad_out,
-            NATIVE_AD_TYPES.native_ad_flow_ad_out,
-        ]
 
         required_message = 'This field is required.'
 
@@ -1268,9 +1270,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
         if billing_type and billing_type not in BILLING_TYPES_MAP[ad_type]:
             errors.append({'billing_type': '"ad_type" and "billing_type" fields not match each other.'})
 
-        if ad_type in TARGET_URL_REQUIRED_FOR and not data.get('target_url'):
-            errors.append({'target_url': required_message})
-
         age_group_from = data.get('age_group_from')
         age_group_to = data.get('age_group_to')
         if not (age_group_from and age_group_to):
@@ -1910,7 +1909,7 @@ class OrderLineSeoSerializer(serializers.Serializer):
     chose which type of target page should be used in the ad? new or existing website
 
     """
-    target_page_type = serializers.ChoiceField(choices=LANDING_PAGE_CHOICES, required=True)
+    target_page_type = serializers.ChoiceField(choices=SEO_LANDING_PAGE_CHOICES, required=True)
 
     """
     url of the target website if LANDING_PAGE_CUSTOMER is chosen in target_page_type
@@ -1967,6 +1966,11 @@ class OrderLineSeoSerializer(serializers.Serializer):
     """
     ticket_id = serializers.CharField(max_length=20, required=False)
 
+    """
+    describes what the customer's expectation regarding the product is.
+    """
+    campaign_goal = serializers.CharField(max_length=1000, allow_blank=True, required=False)
+
 
 class OrderLineWebsiteSerializer(serializers.Serializer):
     """
